@@ -1,11 +1,9 @@
 package Git::Version::Compare;
-$Git::Version::Compare::VERSION = '1.003';
+$Git::Version::Compare::VERSION = '1.004';
 use strict;
 use warnings;
 use Exporter;
-use Carp;
-
-use namespace::clean;
+use Carp ();
 
 my @ops = qw( lt gt le ge eq ne );
 
@@ -75,15 +73,18 @@ sub _normalize {
     return undef if !defined $v;
 
     # minimal consistency check
-    croak "$v does not look like a Git version" if !looks_like_git($v);
+    Carp::croak "$v does not look like a Git version" if !looks_like_git($v);
 
     # reformat git.git tag names, output of `git --version`
-    $v =~ s/^v|^git version |\.msysgit.*|[\012\015]+\z//g;
+    $v =~ s/^v|^git version |\.[a-zA-Z]+\..*|[\012\015]+\z//g;
     $v =~ y/-/./;
     $v =~ s/0rc/0.rc/;
     ($v) = split / /, $v;    # drop anything after the version
+
+    # can't use exists() because the assignment in the @ops created the slot
     return $version_alias{$v} if defined $version_alias{$v};
 
+    # split the dotted version string
     my @v = split /\./, $v;
     my ( $r, $c ) = ( 0, 0 );
 
@@ -95,7 +96,9 @@ sub _normalize {
     ($r) = splice @v, -1 if substr( $v[-1], 0, 2 ) eq 'rc';
     $r &&= do { $r =~ s/rc//; sprintf '-%02d', $r };
 
-    join( '.', map sprintf( '%02d', $_ ), ( @v, 0, 0, 0 )[ 0 .. 3 ] )
+    # compute and cache normalized string
+    return $version_alias{$v} =
+        join( '.', map sprintf( '%02d', $_ ), ( @v, 0, 0, 0 )[ 0 .. 3 ] )
       . ( $r || '.00' )
       . sprintf( '.%04d', $c );
 }
